/*
   HAPI32MC.H - HAPI32 User functions and data structures
   Copyright (c) 1994-1996 Sangoma Technologies Inc.
   Author: Glenn Robins
   API v1.1, 32-bit, January, November 1995, January 1996

   Application include file for HAPI32MC.DLL functions.
   See HAPI32.HLP for a complete function reference.

   Must #include <windows.h> before this header for type
   definitions used here.

   If compiling with Borland C, make sure structures are
   packed on byte boundaries. Link your application with
   HAPI32IM.DEF.

   If compiling with MS Visual C++ and for some reason
   you don't want to use __declspec(dllimport) then define
   SANGOMAIMPORT on the compiler command line. Link a VC++
   application using HAPI32MC.LIB.
*/

#ifndef SANGOMAAPI
#define SANGOMAAPI __cdecl
#endif

#ifdef SANGOMABUILD
#define SANGOMAIMPORT
#endif

#ifndef SANGOMAIMPORT
#if (_MSC_VER >= 800) && !defined(__STDC__)
#define SANGOMAIMPORT __declspec(dllimport)
#else
#define SANGOMAIMPORT
#endif
#endif

#ifndef SANGOMABUILD
#define	SDLAR_NOT_REGISTERED	0L
#define	SDLAR_DEREGISTERED		1L
#define	SDLAR_RELEASED			2L
#define	SDLAR_REGISTERED        1L
#define	SDLAR_ALLOCATED			2L
#define	SDLAR_CARD_BLOCKED		0L
#define	SDLAR_PREPARED			2L
#define	SDLAR_NOT_PREPARED		0L
#define	SDLAR_ERROR_PREPARING	3L
#endif

#define MDATALEN        1027
#define	CB_HEADERLEN	15

/* HIP control block */
#ifdef _MSC_VER
#pragma pack(1)
#endif
typedef struct {
        BYTE command;
	WORD buffer_length;
        BYTE return_code;
        BYTE PF_bit;
        BYTE reserved[6];
        BYTE time_stamp[4];
        BYTE data[MDATALEN];
} CBLOCK;
#ifdef _MSC_VER
#pragma pack()
#endif

#if defined (__cplusplus)
extern "C" {
#endif

/* HAPI will always return 1 */
SANGOMAIMPORT
int SANGOMAAPI HAPIAlive(void);

/* Initializes HAPI and loads SDLA driver, if not loaded already.
   A trace should be registered before this setup if one will
   be used at all, but is not necessary.
   Each application instance MUST call this on initialization.
   returns 0 if failed to load SDLA driver,
	   1 if this is the first setup call and the SDLA driver
	     loaded successfully,
	   2 if this is not the first successful setup call
	     (driver already loaded)
*/
SANGOMAIMPORT
int SANGOMAAPI HAPISetup(void);

/* Cleanup and unloads SDLA driver if this is the last
   application instance to use the driver.
   You must terminate your trace registration first if one
   was registered, unless you are the last application to use
   this DLL (but you shouldn't assume this).
   Each application instance MUST call this before closing.
   returns 1 always (return code reserved for future use)
*/
SANGOMAIMPORT
int SANGOMAAPI HAPICleanup(void);

/* returns non-zero if link in ABM */
SANGOMAIMPORT
int SANGOMAAPI HAPIqLinkInABM(BYTE cardnumber);

/* Emulate XIP interrupt call with control block
   returns return_code value in structure
*/
SANGOMAIMPORT
char SANGOMAAPI HAPIControl(CBLOCK *block, BYTE cardnumber);

/* returns non-zero if trace data is available to be read by
   a READ_TRACE_DATA call
*/
SANGOMAIMPORT
char SANGOMAAPI HAPIqTraceDataAvailable(BYTE cardnumber);

/* returns number of frames pending for read
*/
SANGOMAIMPORT
unsigned char SANGOMAAPI HAPInDataToRead(BYTE cardnumber);

/* returns 1 if clear to send bit is set, 0 if not
*/
SANGOMAIMPORT
char SANGOMAAPI HAPIqClearToXmit(BYTE cardnumber);


/* returns 0 if a debugging command trace is already registered or
   had difficulty creating the window, 1 if successful.
   hWnd is a window to send notification messages to, and
   iMessage is a user-defined message that HAPI will send the
   application to signal an HAPI notification. The actual
   message code is passed by value to the WPARAM parameter
   of the window procedure
*/
SANGOMAIMPORT
char SANGOMAAPI HAPIRegisterDebug(HINSTANCE hInstance, HWND hWnd, UINT iMessage);

/* if a debugging command trace is active and instance matches that passed
   when registered (for security/fault tolerance purposes) then
   trace is terminated and returns 0. If instance doesn't match,
   returns 1. If no trace is running, returns 2.
   The trace is also terminated automatically if the window is
   closed (see trace messages)
*/
SANGOMAIMPORT
char SANGOMAAPI HAPITerminateDebug(HINSTANCE hInstance);

/* returns TRUE if a debugging command trace is registered and active */
SANGOMAIMPORT
BOOL SANGOMAAPI HAPIIsDebugRegistered(void);

/* DEBUGGING COMMAND TRACE MESSAGES (wParam values) */
#define	TRACEMSG_CLOSE	0

/*
   returns SDLAR_NOT_REGISTERED (0L) if failed to obtain a selector
	(any read or write calls to the board will result
	in a general protection fault)
   returns SDLAR_REGISTERED if succeeded (1L): the card's
	instance count was incremented but this is not the
	first registration call for this board (it is already
	in use by an application)
   returns SDLAR_ALLOCATED if succeeded (2L): the card's
	instance count was incremented and this is the
	first registration call for this board, and the
	memory selector was allocated
*/
SANGOMAIMPORT
int SANGOMAAPI HAPIRegisterCard(BYTE cardnumber);

/*
   returns SDLAR_NOT_REGISTERED (0L) if card wasn't registered
   returns SDLAR_DEREGISTERED (1L) if card's instance count
	was decremented but isn't currently zero
	(i.e. an application is still using the specified board)
   returns SDLAR_RELEASED (2L) if card is now not used by
	any application, and the selector was freed
*/
SANGOMAIMPORT
int SANGOMAAPI HAPIDeregisterCard(BYTE cardnumber);

/*
   returns a bit record (32-bit) of cards registered for use
	and cards that exist:
	[ E15 E14 ... E3 E2 E1 E0 R15 R14 ... R3 R2 R1 R0 ]
   For example, if bit R2 is set, then card 2 is registered
		if bit E2 is set, then card 2 exists
			(i.e. a configuration entry exists
			in WIN.INI)
*/
SANGOMAIMPORT
LRESULT SANGOMAAPI HAPIGetCards(void);

/* Undocumented DLL exports - use at own risk */
SANGOMAIMPORT int SANGOMAAPI HAPIPrepareForLoading(BYTE cardnumber);
SANGOMAIMPORT int SANGOMAAPI HAPILoadComplete(BYTE cardnumber);
SANGOMAIMPORT unsigned char SANGOMAAPI HAPIReadPortByte(BYTE cardnumber, WORD offset);
SANGOMAIMPORT void SANGOMAAPI HAPIWritePortByte(BYTE cardnumber, WORD offset, BYTE data);
SANGOMAIMPORT unsigned char SANGOMAAPI HAPIReadByte(BYTE cardnumber, WORD offset);
SANGOMAIMPORT void SANGOMAAPI HAPIWriteByte(BYTE cardnumber, WORD offset, BYTE data);
SANGOMAIMPORT void SANGOMAAPI HAPIZeroWindow(BYTE cardnumber);

#ifdef __cplusplus
}
#endif
